package
module
Version:
v0.0.0-...-8fb0596
Opens a new window with list of versions in this module.
Published: May 4, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
jsonmap-ent
Ent field helper for github.com/ubgo/jsonmap.
Install
go get github.com/ubgo/jsonmap-ent
Use
import (
"entgo.io/ent"
jsonmapent "github.com/ubgo/jsonmap-ent"
)
type Event struct{ ent.Schema }
func (Event) Fields() []ent.Field {
return []ent.Field{
jsonmapent.Field("metadata"),
}
}
For finer control compose field.JSON("metadata", jsonmap.JsonMap{}).Optional()... directly.
License
Apache-2.0 — see LICENSE.
Documentation
¶
Package jsonmapent provides an ent.Field constructor for
github.com/ubgo/jsonmap.JsonMap columns.
Field returns an ent.Field for a jsonmap.JsonMap column. The column
is stored as JSON / JSONB at the SQL layer.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.